==> glue-1.93.0-sources.jar: software/amazon/awscdk/services/glue/InputFormat.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Absolute class name of the Hadoop `InputFormat` to use when reading table files.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.485Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.InputFormat")
public class InputFormat extends software.amazon.jsii.JsiiObject {

    protected InputFormat(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected InputFormat(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AVRO = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "AVRO", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        CLOUDTRAIL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "CLOUDTRAIL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        ORC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "ORC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        PARQUET = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "PARQUET", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        TEXT = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "TEXT", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
    }

    /**
     * @param className This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public InputFormat(final @org.jetbrains.annotations.NotNull java.lang.String className) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(className, "className is required") });
    }

    /**
     * (experimental) InputFormat for Avro files.
     * <p>
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/avro/AvroContainerInputFormat.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat AVRO;

    /**
     * (experimental) InputFormat for Cloudtrail Logs.
     * <p>
     * @see https://docs.aws.amazon.com/athena/latest/ug/cloudtrail.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat CLOUDTRAIL;

    /**
     * (experimental) InputFormat for Orc files.
     * <p>
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/orc/OrcInputFormat.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat ORC;

    /**
     * (experimental) InputFormat for Parquet files.
     * <p>
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/parquet/MapredParquetInputFormat.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat PARQUET;

    /**
     * (experimental) An InputFormat for plain text files.
     * <p>
     * Files are broken into lines. Either linefeed or
     * carriage-return are used to signal end of line. Keys are the position in the file, and
     * values are the line of text.
     * JSON &amp; CSV files are examples of this InputFormat
     * <p>
     * @see https://hadoop.apache.org/docs/stable/api/org/apache/hadoop/mapred/TextInputFormat.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat TEXT;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getClassName() {
        return software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> glue-1.182.0-sources.jar: software/amazon/awscdk/services/glue/InputFormat.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Absolute class name of the Hadoop `InputFormat` to use when reading table files.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.glue.*;
 * InputFormat inputFormat = InputFormat.AVRO;
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:43.456Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.InputFormat")
public class InputFormat extends software.amazon.jsii.JsiiObject {

    protected InputFormat(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected InputFormat(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AVRO = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "AVRO", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        CLOUDTRAIL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "CLOUDTRAIL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        ORC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "ORC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        PARQUET = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "PARQUET", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        TEXT = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.InputFormat.class, "TEXT", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
    }

    /**
     * @param className This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public InputFormat(final @org.jetbrains.annotations.NotNull java.lang.String className) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(className, "className is required") });
    }

    /**
     * (experimental) InputFormat for Avro files.
     * <p>
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/avro/AvroContainerInputFormat.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/avro/AvroContainerInputFormat.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat AVRO;

    /**
     * (experimental) InputFormat for Cloudtrail Logs.
     * <p>
     * @see <a href="https://docs.aws.amazon.com/athena/latest/ug/cloudtrail.html">https://docs.aws.amazon.com/athena/latest/ug/cloudtrail.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat CLOUDTRAIL;

    /**
     * (experimental) InputFormat for Orc files.
     * <p>
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/orc/OrcInputFormat.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/orc/OrcInputFormat.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat ORC;

    /**
     * (experimental) InputFormat for Parquet files.
     * <p>
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/parquet/MapredParquetInputFormat.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/parquet/MapredParquetInputFormat.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat PARQUET;

    /**
     * (experimental) An InputFormat for plain text files.
     * <p>
     * Files are broken into lines. Either linefeed or
     * carriage-return are used to signal end of line. Keys are the position in the file, and
     * values are the line of text.
     * JSON &amp; CSV files are examples of this InputFormat
     * <p>
     * @see <a href="https://hadoop.apache.org/docs/stable/api/org/apache/hadoop/mapred/TextInputFormat.html">https://hadoop.apache.org/docs/stable/api/org/apache/hadoop/mapred/TextInputFormat.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat TEXT;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getClassName() {
        return software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
